@@ -541,8 +541,23 @@ stream.add_argument(
     metavar="DELAY",
     type=num(float, min=0),
     help="""
-    Will retry fetching streams until streams are found while
-    waiting DELAY (seconds) between each attempt.
+    Retry fetching the list of available streams until streams are found
+    while waiting DELAY second(s) between each attempt. If unset, only one
+    attempt will be made to fetch the list of streams available.
+
+    The number of fetch retry attempts can be capped with --retry-max.
+    """
+)
+stream.add_argument(
+    "--retry-max",
+    metavar="COUNT",
+    type=num(int, min=-1),
+    help="""
+    When using --retry-streams, stop retrying the fetch after COUNT retry
+    attempt(s). Fetch will retry infinitely if COUNT is zero or unset.
+
+    If --retry-max is set without setting --retry-streams, the delay between
+    retries will default to 1 second.
     """
 )
 stream.add_argument(
@@ -551,7 +566,8 @@ stream.add_argument(
     type=num(int, min=0),
     default=1,
     help="""
-    Will try ATTEMPTS times to open the stream until giving up.
+    After a successful fetch, try ATTEMPTS time(s)
+    to open the stream until giving up.
 
     Default is 1.
     """
@@ -708,14 +724,40 @@ transport.add_argument(
 
     Default is 10.0.
     """)
+transport.add_argument(
+    "--hls-segment-ignore-names",
+    metavar="NAMES",
+    type=comma_list,
+    help="""
+    A comma-delimited list of segment names that will not be fetched.
+
+    Example: --hls-segment-ignore-names 000,001,002
+
+    This will ignore every segment that ends with 000.ts, 001.ts and 002.ts
+
+    Default is None.
+
+    Note: The --hls-timeout must be increased, to a time that is longer than the ignored break.
+    """
+)
 transport.add_argument(
     "--hls-audio-select",
-    type=str,
+    type=comma_list,
     metavar="CODE",
     help="""
-    Selects a specific audio source, by language code, when multiple audio sources are available.
+    Selects a specific audio source or sources, by language code or name,
+    when multiple audio sources are available. Can be * to download all audio
+    sources.
 
-    Note: This is only useful in special circumstances where the regular locale option fails.
+    Examples:
+
+      --hls-audio-select "English,German"
+      --hls-audio-select "en,de"
+      --hls-audio-select "*"
+
+    Note: This is only useful in special circumstances where the
+    regular locale option fails, such as when multiple sources of the
+    same language exists.
     """)
 transport.add_argument(
     "--hls-timeout",
@@ -1201,13 +1243,6 @@ plugin.add_argument(
     Defaults is 1.
     """
 )
-plugin.add_argument(
-    "--daisuki-mux-subtitles",
-    action="store_true",
-    help="""
-    Automatically mux available subtitles in to the output stream.
-    """
-)
 plugin.add_argument(
     "--rtve-mux-subtitles",
     action="store_true",
@@ -1318,22 +1353,6 @@ plugin.add_argument(
     A bbc.co.uk account password to use with --bbciplayer-username.
     """
 )
-plugin.add_argument(
-    "--neulion-username",
-    "--ufctv-username",
-    metavar="USERNAME",
-    help="""
-    The username used to register with your neulion provider.
-    """
-)
-plugin.add_argument(
-    "--neulion-password",
-    "--ufctv-password",
-    metavar="PASSWORD",
-    help="""
-    A neulion provider account password to use with --neulion-username.
-    """
-)
 plugin.add_argument(
     "--zattoo-email",
     metavar="EMAIL",
@@ -1356,6 +1375,56 @@ plugin.add_argument(
     and reauthenticate.
     """
 )
+plugin.add_argument(
+    "--afreeca-username",
+    metavar="USERNAME",
+    help="""
+    The username used to register with afreecatv.com.
+    """
+)
+plugin.add_argument(
+    "--afreeca-password",
+    metavar="PASSWORD",
+    help="""
+    A afreecatv.com account password to use with --afreeca-username.
+    """
+)
+plugin.add_argument(
+    "--pixiv-username",
+    metavar="USERNAME",
+    help="""
+    The email/username used to register with pixiv.net
+    """
+)
+plugin.add_argument(
+    "--pixiv-password",
+    metavar="PASSWORD",
+    help="""
+    A pixiv.net account password to use with --pixiv-username
+    """
+)
+plugin.add_argument(
+    "--abweb-username",
+    metavar="USERNAME",
+    help="""
+    The username associated with your ABweb account, required to access any ABweb stream.
+    """
+)
+plugin.add_argument(
+    "--abweb-password",
+    metavar="PASSWORD",
+    help="""
+    A ABweb account password to use with --abweb-username.
+    """
+)
+plugin.add_argument(
+    "--abweb-purge-credentials",
+    action="store_true",
+    help="""
+    Purge cached ABweb credentials to initiate a new session
+    and reauthenticate.
+    """
+)
 
 # Deprecated options
 stream.add_argument(
@@ -1374,37 +1443,6 @@ transport.add_argument(
     metavar="fragments",
     help=argparse.SUPPRESS
 )
-plugin.add_argument(
-    "--jtv-legacy-names", "--twitch-legacy-names",
-    action="store_true",
-    help=argparse.SUPPRESS
-)
-plugin.add_argument(
-    "--gomtv-cookie",
-    metavar="cookie",
-    help=argparse.SUPPRESS
-)
-plugin.add_argument(
-    "--gomtv-username",
-    metavar="username",
-    help=argparse.SUPPRESS
-)
-plugin.add_argument(
-    "--gomtv-password",
-    metavar="password",
-    nargs="?",
-    const=True,
-    default=None,
-    help=argparse.SUPPRESS
-)
-plugin.add_argument(
-    "--jtv-cookie",
-    help=argparse.SUPPRESS
-)
-plugin.add_argument(
-    "--jtv-password", "--twitch-password",
-    help=argparse.SUPPRESS
-)
 http.add_argument(
     "--http-cookies",
     metavar="COOKIES",
