@@ -1,5 +1,6 @@
 import errno
 import os
+import platform
 import requests
 import sys
 import signal
@@ -9,8 +10,11 @@ from contextlib import closing
 from distutils.version import StrictVersion
 from functools import partial
 from itertools import chain
+from socks import __version__ as socks_version
 from time import sleep
+from websocket import __version__ as websocket_version
 
+from streamlink import __version__ as streamlink_version
 from streamlink import (Streamlink, StreamError, PluginError,
                         NoPluginError)
 from streamlink.cache import Cache
@@ -398,8 +402,9 @@ def fetch_streams(plugin):
                               sorting_excludes=args.stream_sorting_excludes)
 
 
-def fetch_streams_infinite(plugin, interval):
-    """Attempts to fetch streams until some are returned."""
+def fetch_streams_with_retry(plugin, interval, count):
+    """Attempts to fetch streams repeatedly
+       until some are returned or limit hit."""
 
     try:
         streams = fetch_streams(plugin)
@@ -410,6 +415,8 @@ def fetch_streams_infinite(plugin, interval):
     if not streams:
         console.logger.info("Waiting for streams, retrying every {0} "
                             "second(s)", interval)
+    attempts = 0
+
     while not streams:
         sleep(interval)
 
@@ -418,6 +425,11 @@ def fetch_streams_infinite(plugin, interval):
         except PluginError as err:
             console.logger.error(u"{0}", err)
 
+        if count > 0:
+            attempts += 1
+            if attempts >= count:
+                break
+
     return streams
 
 
@@ -480,8 +492,15 @@ def handle_url():
         console.logger.info("Found matching plugin {0} for URL {1}",
                             plugin.module, args.url)
 
-        if args.retry_streams:
-            streams = fetch_streams_infinite(plugin, args.retry_streams)
+        if args.retry_max or args.retry_streams:
+            retry_streams = 1
+            retry_max = 0
+            if args.retry_streams:
+                retry_streams = args.retry_streams
+            if args.retry_max:
+                retry_max = args.retry_max
+            streams = fetch_streams_with_retry(plugin, retry_streams,
+                                               retry_max)
         else:
             streams = fetch_streams(plugin)
     except NoPluginError:
@@ -719,6 +738,9 @@ def setup_options():
     if args.hls_segment_timeout:
         streamlink.set_option("hls-segment-timeout", args.hls_segment_timeout)
 
+    if args.hls_segment_ignore_names:
+        streamlink.set_option("hls-segment-ignore-names", args.hls_segment_ignore_names)
+
     if args.hls_timeout:
         streamlink.set_option("hls-timeout", args.hls_timeout)
 
@@ -862,9 +884,6 @@ def setup_plugin_options():
     if args.schoolism_part:
         streamlink.set_plugin_option("schoolism", "part", args.schoolism_part)
 
-    if args.daisuki_mux_subtitles:
-        streamlink.set_plugin_option("daisuki", "mux_subtitles", args.daisuki_mux_subtitles)
-
     if args.rtve_mux_subtitles:
         streamlink.set_plugin_option("rtve", "mux_subtitles", args.rtve_mux_subtitles)
 
@@ -936,17 +955,6 @@ def setup_plugin_options():
     if bbciplayer_password:
         streamlink.set_plugin_option("bbciplayer", "password", bbciplayer_password)
 
-    if args.neulion_username:
-        streamlink.set_plugin_option("neulion", "username", args.neulion_username)
-
-    if args.neulion_username and not args.neulion_password:
-        neulion_password = console.askpass("Enter ufc.tv account password: ")
-    else:
-        neulion_password = args.neulion_password
-
-    if neulion_password:
-        streamlink.set_plugin_option("neulion", "password", neulion_password)
-
     if args.zattoo_email:
         streamlink.set_plugin_option("zattoo", "email", args.zattoo_email)
     if args.zattoo_email and not args.zattoo_password:
@@ -960,30 +968,40 @@ def setup_plugin_options():
         streamlink.set_plugin_option("zattoo", "purge_credentials",
                                      args.zattoo_purge_credentials)
 
-    # Deprecated options
-    if args.jtv_legacy_names:
-        console.logger.warning("The option --jtv/twitch-legacy-names is "
-                               "deprecated and will be removed in the future.")
+    if args.afreeca_username:
+        streamlink.set_plugin_option("afreeca", "username", args.afreeca_username)
 
-    if args.jtv_cookie:
-        console.logger.warning("The option --jtv-cookie is deprecated and "
-                               "will be removed in the future.")
+    if args.afreeca_username and not args.afreeca_password:
+        afreeca_password = console.askpass("Enter afreecatv account password: ")
+    else:
+        afreeca_password = args.afreeca_password
 
-    if args.jtv_password:
-        console.logger.warning("The option --jtv-password is deprecated "
-                               "and will be removed in the future.")
+    if afreeca_password:
+        streamlink.set_plugin_option("afreeca", "password", afreeca_password)
 
-    if args.gomtv_username:
-        console.logger.warning("The option --gomtv-username is deprecated "
-                               "and will be removed in the future.")
+    if args.pixiv_username:
+        streamlink.set_plugin_option("pixiv", "username", args.pixiv_username)
 
-    if args.gomtv_password:
-        console.logger.warning("The option --gomtv-password is deprecated "
-                               "and will be removed in the future.")
+    if args.pixiv_username and not args.pixiv_password:
+        pixiv_password = console.askpass("Enter pixiv account password: ")
+    else:
+        pixiv_password = args.pixiv_password
 
-    if args.gomtv_cookie:
-        console.logger.warning("The option --gomtv-cookie is deprecated "
-                               "and will be removed in the future.")
+    if pixiv_password:
+        streamlink.set_plugin_option("pixiv", "password", pixiv_password)
+
+    if args.abweb_username:
+        streamlink.set_plugin_option("abweb", "username", args.abweb_username)
+    if args.abweb_username and not args.abweb_password:
+        abweb_password = console.askpass("Enter ABweb password: ")
+    else:
+        abweb_password = args.abweb_password
+    if abweb_password:
+        streamlink.set_plugin_option("abweb", "password", abweb_password)
+
+    if args.abweb_purge_credentials:
+        streamlink.set_plugin_option("abweb", "purge_credentials",
+                                     args.abweb_purge_credentials)
 
 
 def check_root():
@@ -992,6 +1010,26 @@ def check_root():
             console.logger.info("streamlink is running as root! Be careful!")
 
 
+def log_current_versions():
+    """Show current installed versions"""
+    if args.loglevel == "debug":
+        # MAC OS X
+        if sys.platform == "darwin":
+            os_version = "macOS {0}".format(platform.mac_ver()[0])
+        # Windows
+        elif sys.platform.startswith("win"):
+            os_version = "{0} {1}".format(platform.system(), platform.release())
+        # linux / other
+        else:
+            os_version = platform.platform()
+
+        console.logger.debug("OS:         {0}".format(os_version))
+        console.logger.debug("Python:     {0}".format(platform.python_version()))
+        console.logger.debug("Streamlink: {0}".format(streamlink_version))
+        console.logger.debug("Requests({0}), Socks({1}), Websocket({2})".format(
+            requests.__version__, socks_version, websocket_version))
+
+
 def check_version(force=False):
     cache = Cache(filename="cli.json")
     latest_version = cache.get("latest_version")
@@ -1031,6 +1069,7 @@ def main():
     setup_console()
     setup_http_session()
     check_root()
+    log_current_versions()
 
     if args.version_check or (not args.no_version_check and args.auto_version_check):
         with ignored(Exception):
